## Basic usage

{

lists | : | [ 1 2 3.14159 ]
tuples | : | ( True False )
dataclasses | : | Point
x | = | 10
y | = | 20
null | : | None

}

#### Setting max_depth=1

{

lists | : | [ ... ]
tuples | : | ( ... )
dataclasses | : | Point ...
null | : | None

}

#### Recursive data structures

#1=
{

lists | : | [ 1 2 3.14159 ]
tuples | : | ( True False )
dataclasses | : | Point
x | = | 10
y | = | 20
null | : | None
recursive | : | ⟳1= { ... }

}

#### A list of three of the same object

[
#1=
Amelia

age | ↦ | 35
job | ↦ | gardener

#1=Amelia
]

#### Same, but shortrefs=True

[
#1=
Amelia

age | ↦ | 35
job | ↦ | gardener

#1
]

#### Same, but norefs=True

[
Amelia

age | ↦ | 35
job | ↦ | gardener

Amelia

age | ↦ | 35
job | ↦ | gardener

Amelia

age | ↦ | 35
job | ↦ | gardener

]

## Custom representation

[
]

#### Varying configuration values

[
]

#### Without a mixin

[
1
2
#1=<__main__.Farfetchd>
4
#1=<__main__.Farfetchd>
]

#### With a custom mixin

[
The number 1
The number 2
🦆
The number 4
🦆
]

#### Playing with max_depth

[
1
2
🦆
4
🦆
]

#### Use a postprocessor to highlight the number 2

[
1
2
[
3
[
2.0
]
2
]
]

## Cool stuff

#### Plot with plotly

#### Graph with cytoscape

[
]